/* Object: buildings
 * Holds information on buildings in-game along with the methods to gather and 
 * store details of the buildings currently in towns.
 * 
 * Properties:
 * bldgs - object. Details of all the buildings available in the game. Organised 
 * by in-game building id.
 * maxPops - object. The maximum possible population of each building. Organised 
 * by building name.
 * 
 * Methods:
 * bldgScan - Scan and store the building levels for the current town. Requires 
 * you be viewing the town map.
 * bldgsDisplay - Display name, current level and maximum population of the 
 * buildings and resource plots in the current town.
 * bldgSearch - Display select box to search all towns for a given building. 
 * Calls <showLvls> on change.
 * showLvls - Display the results of a search.
 */
dt.buildings = {
    /* Method: bldgDescSelect
     * Display the form to select the building desc to display
     */
    bldgDescSelect: function(){
      dt.showTool("#bldgDescHtml");
    },
    
    /* Method: showDesc
     * Show the official description of the selected building.
     */
    showDesc: function () {
        var selBldg = document.querySelector('#bldgDescInp').value;
        var out = document.querySelector("#bldgDescDisp");
        var bld = dt.buildings.bldgs[selBldg];
    //    out.setAttribute("title",bld[0]);
        out.innerHTML = bld[2];
        dt.showTool("#bldgDescDisp");
        $( "#bldgDescDisp" ).dialog( "option", "title", bld[0] );
        var dummy = "";
    },

    /* Method: bldgScan
     * Scans and stores the building levels for the current town.
     */
    bldgScan: function () {
        var msg = "Scanning building levels.";
        dt.logEntry(msg);
        if (window.location == 'https://elgea.illyriad.co.uk/#/Town/Map') {
            var plots = {
                resource: {1: "", 2: "", 3: "", 4: "", 5: "", 6: "", 7: "", 8: "", 9: "", 10: "", 11: "", 12: "", 13: "", 14: "", 15: "", 16: "", 17: "", 18: "", 19: "", 20: "", 21: "", 22: "", 23: "", 24: "", 25: ""},
                internal: {0: "", 1: "", 2: "", 3: "", 4: "", 5: "", 6: "", 7: "", 8: "", 9: "", 10: "", 11: "", 12: "", 13: "", 14: "", 15: "", 16: "", 17: "", 18: "", 19: "", 20: "", 21: "", 22: "", 23: "", 24: "", 25: ""}
            };
            var srccont = document.querySelector("#townMapOutline");
            var areas = srccont.querySelectorAll("area");
            // Step through each of the areas and extract the plot, name and lvl of the building.
            for (i = 0; i < areas.length; i++) {
                var title = areas[i].getAttribute("title");
                var h = areas[i].getAttribute("href");
                var hparts = h.split('/');
                var t = hparts[2].split('?');
                if (t.length === 1) {
// Standard building
                    var s = title.split('[');
                    var bldgName = s[0].trim();
//				bldgName = bldgName.replace("'","");
                    var bldgLvl = s[1].replace(']', '').trim();
                    if (hparts[3] === "1") {
                        plots.resource[hparts[4]] = [bldgName, bldgLvl];
                    } else {
                        plots.internal[hparts[4]] = [bldgName, bldgLvl];
                    }
                } else {
// Castle
                    var s = title.split('[');
                    var bldgName = 'Wall';
                    var s2 = s[1].split(' ');
                    var bldgLvl = s2[1].replace(']', '').trim();
                    plots.internal[0] = [bldgName, bldgLvl];
                }
            }
            dt[PlayerId].towns[CurrentTown].plots = plots;
            var key = CurrentTown + ':plots';
            locStorage.setItem(key, JSON.stringify(dt[PlayerId].towns[CurrentTown].plots));
        }
        var msg = "Building level scan finished.";
        dt.logEntry(msg);
    },
    /* Method: bldgsDisplay
     * Display details of the buildings and resource plots in the town supplied. 
     * Also calculates and displays the maximum possible population with the 
     * current buildings at maximum levels.
     * 
     * Parameters:
     * town - integer. The id of the town to display the info for.
     * dest - string. The id of the location to place the output in.
     */
    bldgsDisplay: function () {
        dt.showTool("#buildingsHtml");
        var town = CurrentTown;
        var maxPop = 0;
        var t = dt[PlayerId].towns[town].plots;
        var resTbl = document.querySelector("#tResPlots");
        var bldgTbl = document.querySelector("#tBldgs");
        dt.removeRows(resTbl);
        dt.removeRows(bldgTbl);
        var k = Object.keys(t.resource);
        var tBdy = resTbl.querySelector("tbody");
        for (i = 0; i < k.length; i++) {
            var mp = 0;
            if (this.maxPops.hasOwnProperty(t.resource[k[i]][0])) {
                mp = this.maxPops[t.resource[k[i]][0]];
            }
            if (typeof t.resource[k[i]][0] != 'undefined') {
                var row = tBdy.insertRow(-1);
                var cell = row.insertCell(0);
                cell.innerHTML = '<a href="#/Town/Building/1/' + (i + 1) + '">' + t.resource[k[i]][0] + '</a>';
                cell = row.insertCell(1);
                cell.classList.add("tCenter");
                cell.textContent = t.resource[k[i]][1];
                cell = row.insertCell(2);
                cell.classList.add("tCenter");
                cell.textContent = mp;
                maxPop += mp;
            }
        }
        var k = Object.keys(t.internal);
        tBdy = bldgTbl.querySelector("tbody");
        for (i = 0; i < k.length; i++) {
            var mp = 0;
            if (this.maxPops.hasOwnProperty(t.internal[k[i]][0])) {
                mp = this.maxPops[t.internal[k[i]][0]];
            }
            var row = tBdy.insertRow(-1);
            var cell = row.insertCell(0);
            cell.innerHTML = '<a href="#/Town/Building/0/' + i + '">' + t.internal[k[i]][0] + '</a>';
            cell = row.insertCell(1);
            cell.classList.add("tCenter");
            cell.textContent = t.internal[k[i]][1];
            cell = row.insertCell(2);
            cell.classList.add("tCenter");
            cell.textContent = mp;
            maxPop += mp;
        }
    },
    /* Method: bldgSearch
     * Display a select box to search all towns for a given building. Calls <showLvls> 
     * on change.
     */
    bldgSearch: function () {
        dt.showTool("#bldgSearchHtml");
    },
    /* Method: showLvls
     * Display the results of a building search.
     */
    showLvls: function () {
        var selBldg = document.querySelector('#bldgSearchInp').value;
        var outTbl = document.querySelector("#bldgSearchResults tbody");
        var twnList = dt[PlayerId].towns.list;
        var r = '';
        for (var twn = 0; twn < twnList.length; twn++) {
            var twnId = twnList[twn];
            var tName = dt[PlayerId].towns[twnId].name;
            var obj = dt[PlayerId].towns[twnId].plots.internal;
            for (var prop in obj) {
                bldgLvl = 0;
                if (obj.hasOwnProperty(prop) && obj[prop][0] === selBldg) {
                    bldgLvl = obj[prop][1];
                    var row = outTbl.insertRow(-0);
                    var cell = row.insertCell(0);
                    cell.textContent = tName;
                    cell = row.insertCell(1);
                    cell.textContent = bldgLvl;
                }
            }
            var obj = dt[PlayerId].towns[twnId].plots.resource;
            for (var prop in obj) {
                bldgLvl = 0;
                if (obj.hasOwnProperty(prop) && obj[prop][0] === selBldg) {
                    bldgLvl = obj[prop][1];
                    var row = outTbl.insertRow(-0);
                    var cell = row.insertCell(0);
                    cell.textContent = tName;
                    cell = row.insertCell(1);
                    cell.textContent = bldgLvl;
                }
            }
        }
    },
    /* Object: bldgs
     * Details of all the buildings available in the game. Organised by in-game 
     * building id. Each building is an array holding the name and maximum 
     * population when the building is fully leveled.
     */
    bldgs: {0: ["Wall", 20, "Every city needs to be defended, and it is here that the City Wall comes into its own. Encircling the very heart of your city, and protecting the buildings within, the City Wall provides a defensive bonus to any troops currently stationed in your city.</br>Upgrading the City Wall increases your city's defence bonus."],
        1: ["Storehouse", 37, "Your workers are diligently working; hewing rock, felling timber, cutting clay, growing food, tending cattle, brewing beer, making armour....and much more. But where do you store the fruits of all this labour? In the Storehouse of course!</br>Upgrading your Storehouse will ensure you have room to store your commodities as your stocks grow. However, be aware that devious thieves and attacking armies may have designs on your hard-earned resources and goods, and your Storehouse will not protect them; you will need to build a Vault as well.</br>And when you need even more storage space, once your Storehouse reaches Level 15, you'll be able to build a Warehouse too!"],
        2: ["Lumberjack", 37, "Your Lumberjacks work tirelessly in the forests to produce timber to make buildings, books, bows, horse tack (saddles/bridles), and to fire the furnaces of the Blacksmith and Forge.</br>The larger the building is (i.e. the higher the level of the Lumberjack), the more timber it can produce per hour.</br>Upgrading the Lumberjack will unlock research which enables you to build a Carpentry, which in turn will increase overall wood production per hour.</br>It should be noted however, that raising taxes will cause your workers to become disgruntled and not well-disposed toward working hard, thus resulting in a decrease in production.</br>In addition, should this resource production drop to below zero, and your stored supplies run out, then any sovereign structures and then buildings which use this resource will begin to level down."],
        3: ["Clay Pit", 37, "Each day the Clay Cutters go out to cut clay, which is used to make bricks for buildings, and during the manufacturing process for swords and armour.</br>The larger the building is (i.e. the higher the level of the Clay Cutter), the more clay it can produce per hour.</br>Upgrading the Clay Pit will unlock research which enables you to build a Kiln, which in turn will increase overall clay production per hour.</br>It should be noted however, that raising taxes will cause your workers to become disgruntled and not well-disposed toward working hard, thus resulting in a decrease in production.</br>In addition, should this resource production drop to below zero, and your stored supplies run out, then any sovereign structures and then buildings which use this resource will begin to level down."],
        4: ["Iron Mine", 37, "Excavating the mountainside is often back-breaking work but your diligent Iron Miners hack away at the rock in order to provide iron ore which can then be extracted and used in many ways; from fixtures and fittings in buildings, to weapons and armour, tack for horses, and the iron bands around beer barrels.</br>The larger the building is (i.e. the higher the level of the Iron Mine), the more iron it can produce per hour.</br>Upgrading the Iron Mine will unlock research which enables you to build a Foundry, which in turn will increase overall iron production per hour.</br>It should be noted however, that raising taxes will cause your workers to become disgruntled and not well-disposed toward working hard, thus resulting in a decrease in production.</br>In addition, should this resource production drop to below zero, and your stored supplies run out, then any sovereign structures and then buildings which use this resource will begin to level down."],
        5: ["Quarry", 37, "In your Quarries, your men and women work hard to cut stone which is then used for buildings and in the production of swords.</br>The larger the building is (i.e. the higher the level of the Quarry), the more stone it can produce per hour.</br>Upgrading the Quarry will unlock research which enables you to build a Stonemason, which in turn will increase overall stone production per hour.</br>It should be noted however, that raising taxes will cause your workers to become disgruntled and not well-disposed toward working hard, thus resulting in a decrease in production.</br>In addition, should this resource production drop to below zero, and your stored supplies run out, then any sovereign structures and then buildings which use this resource will begin to level down."],
        6: ["Farmyard", 37, " It goes without saying that without food, your hamlet, village, town, or city cannot thrive. In fact too little food will result in your workers leaving, seeking gainful employment elsewhere in Illyriad: should both your food production and stores simultaneously drop to zero or below, your buildings will begin to drop in size (i.e. levels will decrease)... thus a serious food crisis can potentially wipe out your town. Therefore, keeping the bellies of your citizens, workers, and livestock full is essential. Food crops are also used to make beer, which some argue is also essential.</br>The larger the building is (i.e. the higher the level of the Farmyard), the more food it can produce per hour.</br>Upgrading the Farmyard will unlock research which enables you to build a Flourmill, which in turn will increase overall food production per hour.</br>It should be noted however, that raising taxes will cause your workers to become disgruntled and not well-disposed toward working hard, thus resulting in a decrease in production.</br>In addition, should this resource production drop to below zero, and your stored supplies run out, then any sovereign structures and then buildings which use this resource will begin to level down."],
        7: ["Library", 37, "In the Library, your academics are studying day and night, providing you with the necessary research to further technological advancement in your town, city, etc. Research enables your citizens to build new buildings, as well as allowing advancement in magic, military, diplomacy, trade, and quests. It also allows you to maintain Sovereignty.</br>Improving buildings in your town will enable further research into each one's relevant field.</br>Building a Bookbinder in your town will enable your people to not only produce books to sell at market but also to trade them in for research points in your Library's reading room. In addition, if another player sends you books, you can turn these into research points as well.</br>The larger your Library (the higher its level), the more research points it produces per hour."],
        8: ["Barracks", 37, "When not out occupying territories, fighting for the continued liberty of your citizens, defending their homeland, or clearing the way for your caravans to harvest resources, your troops live in the Barracks. It is here that they engage in training - mastering the new skills your academics have researched.</br>New troops are produced here, armies built, and Commanders resurrected and promoted (levelled up).</br>From the Barracks, orders are given and your troops despatched.</br>The larger the Barracks (i.e. the higher the level), the faster your troops are recruited (produced). Upgrading the Barracks also unlocks more research, thus enabling the recruitment of more troop types, additional tactics and commands, and enables you to build specialist military schools."],
        9: ["Marketplace", 37, " The Marketplace is the bustling hub of your town's trading network. Here your merchants buy, sell, and barter goods in order to increase your town's wealth and growth. Your caravans are housed in the Marketplace, and despatched to engage in trade with other players, send goods and gold to your other towns and cities, and harvest resources.</br>Improving the Marketplace enables increased Caravan speed (one square per hour per level of Marketplace).</br>In addition, upgrading the Marketplace unlocks research into faster loading and gathering times and improved carrying capacity, the ability to avoid being intercepted by hostile players, run blockades, and break trade embargoes, and the technology to house larger numbers of Caravans.</br>The Market is the place where you recruit all of your trade-related units. At first you can recruit Caravans here. Later, depending on the Researches which you complete and the buildings which you build, you may also be able to hire Cotters, Miners, Skinners, Herbalists and Traders."],
        10: ["Brewery", 40, " Beer... the lifeblood of every city! Beer... makes the world go around! At least, according to some. What is certainly true is that if your people wish to engage in Quests, they will need to be able to provide beer to ensure that negotiations go smoothly. Of course, it can be bought from the market but why give others your hard-earned money when you have all you need to build your own Brewery in your city?</br>Improving the Brewery (upgrading it) allows your brewers to produce barrels of beer more quickly (4.5% per level), and puts a smile of the faces of your citizens!</br>At first, you can produce Beer here, which requires only common resources, produced by your town. If you later complete the Wine Making Research, you will also be able to produce Wine here, but good wine-making grapes are rare."],
        11: ["Tavern", 1497, "If beer is the lifeblood of every city, then the Tavern is one of your city's most important buildings; essential for entertaining, socialising, providing respite for weary travellers, and taking on Quests. Spend a typical evening in the Tavern of any city, and you will witness deals being made and broken, hear tall tales of heroism and unimaginable bravery, and of course, quaff beer!</br>Without a Tavern, your citizens will be unable to go on Quests. Upgrading the Tavern not only increases the rate at which new Quests are offered (1% per level) but also extends the time in which they must be completed (1% per level)."],
        12: ["Consulate", 1497, "The hub of your city's diplomatic activity is the Consulate; it is here that your foreign relationships and endeavours are planned and executed.</br>Your spies, scouts, saboteurs, assassins, thieves, and envoys are trained and despatched from the Consulate, and each improvement to the building (level upgrade) decreases the amount of time it takes to produce these diplomatic units. In addition, upgrading your Consulate extends your foreign diplomat warning radius (on top of the 5-square default) by half a square per level.</br>Further Diplomacy research may be unlocked by upgrading the Consulate, which in turn leads to the ability to build specialist diplomatic buildings in your city."],
        13: ["Carpentry", 1497, "Wood produced by your Lumberjacks is taken from the forests to the carpenter to be sawn and planed into precisely-measured planks and beams with which to build your city's structures. Wood is also essential for the production of buildings, books, bows, horse tack (saddles/bridles), and to fire the furnaces of the Blacksmith and Forge.</br>Improving the Carpentry increases the overall amount of timber produced per hour by 2% per level."],
        14: ["Kiln", 1497, "What happens to all the clay which your Clay Pits produce? With a Kiln, your potters and brick makers apply their considerable skills to the manufacture of many items which are essential in the production of buildings, swords, and armour.</br>Increasing the efficiency of the Kiln (by upgrading it) will see a steady increase in clay production at the rate of 2% per hour per level."],
        15: ["Foundry", 1497, "The fires of the Foundry's forge burn hot, as raw iron ore is smelted and refined, ensuring its suitability for all the metalwork needs of your city.</br>Increasing the efficiency of the Foundry (by upgrading it) will see a steady increase in iron production at the rate of 2% per hour per level."],
        16: ["Stonemason", 1497, " Carefully selecting only the finest stone from your Quarries, your stonemasons cleave and chisel raw rock, turning it into dressed blocks for your city's use.</br>Increasing the efficiency of the Stonemason (by upgrading it) will see a steady increase in stone production at the rate of 2% per hour per level."],
        17: ["Flourmill", 16, "Sorting the wheat from the chaff, and grinding it into flour takes time and effort, yet without it there can be no bread. Building a Flourmill speeds the winnowing and grinding processes, thus greatly improving the overall food production time of your city.</br>Increasing the efficiency of the Flourmill (by upgrading it) will see a steady increase in food production at the rate of 2% per hour per level."],
        18: [],
        19: ["Common Ground", 1497, " The Common Ground is an area within the city walls upon which your citizens, by virtue of an ancestral right, are able to graze their cattle. This livestock is then used by your City's Saddlemakers and Tanners to meet the city's leather needs.</br>Upgrading the Common Ground will see a steady increase in the speed of livestock-breeding at the rate of 4.5% per level."],
        20: [],
        21: ["Paddock", 1497, "Improving The Paddock means that your city's breeders can raise the finest thoroughbred foals, which will then serve your merchants , diplomats, and the military.</br>Upgrading the Paddock will see a steady increase in the speed of horse-breeding at the rate of 4.5% per level.</br>If you unlock the Horse Training Research and build a Horse Trainer in this settlement, then you will also be able to train your horses to produce superior steeds in this Paddock."],
        22: [],
        23: [],
        24: ["Vault", 37, "Your Storehouse and Warehouse, either together or alone, are not enough to protect your hard-earned resources and goods from thieves and attacking armies; therefore you will need to build a Vault .</br>Enlarging your Vault (by upgrading it) will, of course, increase the amount of resources protected. "],
        25: [],
        26: ["Mage Tower", 1497, "The Mage Tower is home to your keepers of arcane knowledge, who work day and night preparing and maintaining spells and charms to protect your city and aid its resource production, or send blights against your foes.</br>Upgrading the Mage Tower will increase the amount of Mana produced hourly, which is essential for sustaining your mages' cast magics and for weaving new enchantments."],
        27: [],
        28: ["Fletcher", 1497, "Your bowyers and fletchers work side-by-side here, using their considerable skills to produce the finest ranged weapons for your armies.</br>Increasing the efficiency of the Fletcher decreases the amount of time it takes to produce a Bow by 4.5% per level.</br>If you complete the Bowyer research and build a separate Bowyer's building, then the Fletcher will also be able to produce superior Bows."],
        29: [],
        30: [],
        31: ["Spearmaker", 1497, " While they may be considered the most basic of weapons, Spears must nevertheless be strong enough to penetrate armour, while at the same time being light enough to not be clumsy; therefore, the Spearmaker must be a highly-skilled craftsman.</br>Upgrading the Spearmaker decreases the amount of time it takes to produce a Spear by 4.5% per level.</br>If you complete the Spearsmith research and build a separate Spearsmith's building, then this Spearmaker will also be able to produce superior Spears."],
        32: ["Blacksmith", 1497, "Fanned into life by sweating apprentices who tirelessly pump the bellows, the fires of the Blacksmith's furnaces burn white-hot, tempering steel so that the smith can apply his craft to the manufacture of Swords and Chainmail for your armies.</br>Upgrading the Blacksmith decreases the amount of time it takes to produce Swords and Chainmail by 4.5% per level.</br>If you complete the Swordsmith research and build a separate Swordsmith's building, then this Blacksmith will also be able to produce superior Swords. Likewise, a Chain Armourer will allow you to produce upgraded Chainmail here."],
        33: ["Forge", 1497, "As your army becomes advanced, so its need for better armour grows. When this happens, a group of Blacksmiths can band together and build a Forge... the only building in your city with the facilities to manufacture Plate Steel armour.</br>Upgrading the Forge decreases the amount of time it takes to produce Plate Steel by 4.5% per level.</br>If you complete the Plate Armourer research and build a separate Plate Armourer's building, then this Forge will also be able to produce superior Plate armours."],
        34: ["Tannery", 1497, "It is well-known that most folk would rather live upwind of the Tannery; however, it is also well-known that many soldiers trust in the sturdy Leather armour that it produces to protect them in battle.</br>Upgrading the Tannery decreases the amount of time it takes to produce Leather armour by 4.5% per level.</br>If you complete the Leather Armourer research and build a separate Leather Armourer's building, then the Tannery will also be able to produce superior suits of Leather armour."],
        35: ["Saddlemaker", 1497, " The Saddlemaker takes care of all your city's equine tack needs; from the mercantile to the military, your city's horsemen are always furnished with the best equipment for their steeds and beasts of burden.</br>Upgrading the Saddlemaker decreases the amount of time it takes to produce a Saddle by 4.5% per level."],
        36: ["Siege Workshop", 1497, " The most advanced military building available, the Siege Workshop is where the mighty Siege Engine construction blocks are produced. These blocks are then used to construct the massive weapons of war necessary for destroying or capturing an enemy city.</br>Upgrading the Siege Workshop decreases the amount of time it takes to produce Siege Blocks by 4.5% per level."],
        37: ["Book Binder", 1497, "Taking wood pulp, and pressing and drying it to produce the finest leaves which can then be bound into manuscripts, the Bookbinder's craft is highly-skilled. This is of course, in addition to his considerable skill as a scribe; taking research notes - which his apprentices collect from the scholars in the city's Library - and turning them into beautifully-illuminated and intricately-bound highly detailed tomes. It comes as no great surprise therefore, that the Bookbinder is also very well-paid!</br>Books can be used to train diplomatic units. They can also be used in the Reading Room of a Library to generate Research Points, to which end Books are frequently sent from established settlements to newer, less well educated, villages, so that the Research of one can be made available to the people of the other.</br>Upgrading the Bookbinder decreases the amount of time it takes to produce a book by 4.5% per level."],
        38: [],
        39: ["Warehouse", 370, "Working in tandem with the Storehouse, your Warehouse affords greater storage space for your city's resources and goods. Being the larger of the two buildings of course means that the Warehouse costs more to build; however, each upgrade significantly increases the overall maximum storage capacity of your city."],
        40: ["Chancery of Estates", 449, "Aiding the complex task of land management, the Chancery of Estates helps with the administration of your Level 1 Sovereignty by maintaining a registry of low-level claims, thus streamlining the process for your vassals. This gives a 2% reduction (per building level) to the cost of claiming Level 1 Sovereignty on a square.</br>The wise ruler who wishes to lay claim to a lot of land around his or her city makes this building a priority.</br>You may build multiple Chanceries; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        41: [],
        42: ["Runemasters Grounding", 898, " Providing an environment which is safe and comfortable for your Runemasters while they tinker with the intricate patterns and materials used in Rune construction (and safely away from your citizens too), the Runemasters' Grounding is both research centre and testing ground in which to hone and perfect their Runeweaving skills.</br>Although there is an increase in the resultant charges arising from the additional preparation of these Runeweavings, this only applies to newly-cast Runes, not existing ones.</br>You may build multiple Runemasters' Groundings; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        43: ["Geomancers Retreat", 898, "Communing and becoming at one with nature and the natural spirits which bind the land together is how Geomancers spend a goodly amount of their time. It therefore comes as no surprise that in order to replenish the considerable mental energies expended in these pursuits, a purpose-built retreat enables them to recoup their vim and cast more effective geomancy spells.</br>You may build multiple Geomancers' Retreats; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        44: [],
        45: ["Scouts Lookout", 898, "Since Scouts, quite naturally, spend a lot of time away from the city on missions, knowing that their families are being well-cared for in these purpose-built homes means that they're willing to forego some of their pay, thus costing you less to maintain them.</br>You may build multiple Scouts' Lookouts; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        46: ["Spies Hideout", 898, "Seamlessly blending into their surroundings is a prerequisite of being a Spy, and having a secret hideout where they can hone the cunning arts of disguise and misdirection means that they're willing to forego some of their pay, thus costing you less to maintain them.</br>You may build multiple Spies' Hideouts; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        47: ["Thieves Den", 898, "Whether breaking and entering, silently moving among the shadows, surreptitiously appropriating items, or disappearing into the night, Thieves must continuously hone their considerable skills. The Thieves' Den allows them to practise their art, without fear of misunderstanding or reprisals from the rest of your citizens, and for this, they are more than willing to forego some of their pay, thus costing you less to maintain them.</br>You may build multiple Thieves' Dens; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        48: ["Saboteurs Sanctuary", 898, "To the uninformed, undermining, arson and industrial espionage seem to be easy tasks � surely it's just a case of digging holes, burning things down and causing some mindless mayhem! However, in addition to the intensive and ongoing fitness training your Saboteurs must go through, there is the matter of rest and recuperation... after all, being so destructive takes its toll. For the convenience of having a Sanctuary where they can safely recoup their energy, they are more than willing to forego some of their pay , thus costing you less to maintain them.</br>You may build multiple Saboteurs' Sanctuaries; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        49: ["Assasins Abode", 898, "Assassins may be your city's most efficient killers; however, at some point they need to sleep... and that somewhere obviously needs to be secure... and safe from other cities' assassins. They are therefore more than willing to forego some of their pay for the convenience of having a safe haven, thus costing you less to maintain them.</br>You may build multiple Assassins' Abodes; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        50: ["Spearmens Billets", 1796, " It is a tragic fact that the one absolute truth which all Spearmen know is that they are the most expendable part of any army. However, knowing this does not mean that they accept it, and so they spend almost every waking moment practising their craft, ever hopeful that their efforts will turn this truth into a legend.</br>For the hope of being able to cheat almost certain death, they are therefore more than willing to forego some of their pay (thus costing you less to maintain them )if it means they have a home in which they can practise their skills and boost each other's morale.</br>You may build multiple Spearmens' Billets; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        51: ["Archers Field", 1796, "An archer has a serenity about him (or her); a serenity which comes from the mental and physical discipline which enables them to be at one with their target. Under normal circumstances, this would be impossible within the confines of everyday life in the Barracks, so the Archers' Field provides a tranquil place in which to practise their skill, and to live with their peers who understand the need for calm.</br>For this haven, free from interruption, they are more than happy to forego some of their pay, thus costing you less to maintain them.</br>You may build multiple Archers' Fields; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        52: ["Infantry Quarters", 1796, "The backbone of any army is its infantry, and as anyone who has ever visited a tavern on a Saturday night will know, camaraderie is something these troops are not short of! It therefore behoves any city to build Infantry Quarters, where their skills, both military and filial, are honed to perfection, producing a tightly-knit and highly-effective fighting community.</br>For these Quarters, away from the distractions of the city's taverns (and subsequent run-ins with the constable), they are more than happy to forego some of their pay, thus costing you less to maintain them.</br>You may build multiple Infantry Quarters; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        53: ["Cavalry Parade Ground", 1796, "Not everyone in a city's army sees the Cavalry as the elite standard-bearers they consider themselves to be, and this attitude has on occasion led to certain members becoming the victims of practical jokes at the hands of the common soldiers - a favourite being the placing of a dead fish under a saddle on a hot day (�... now ee's got a reason to look as though ee's got a bad smell under �is nose!�).</br>Building a Cavalry Parade Ground ensures that these elite troops can practise their horsemanship skills, such as dressage (\"... poncing about like girls\" as it's described by the other ranks), and for this, the Cavalry troops are more than happy to forego some of their pay, thus costing you less to maintain them.</br>You may build multiple Cavalry Parade Grounds; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        54: [],
        55: ["Architects\' Office", 328, "It is not enough for a building to be aesthetically pleasing (although there is no denying that this is a good thing), it must be practical and structurally-sound as well, plus ideally, not go over budget. The architect's task therefore, is to ensure that all safety requirements are met, implement new efficient designs, and devise safe methods of building which result in faster construction times.</brBuilding and upgrading an Architects' Office will reduce construction times of new buildings in your city by 1.5% per level (of Office).</br>This decrease in construction time only affects new building orders, not existing ones which have been queued. "],
        56: ["Foreign Office", 898, "Keeping a vigilant watch for foreign interlopers is a skilled task, which requires not only early detection skills but also the ability to be able to recognise, identify, and report on such nefarious scoundrels crossing your borders.</br>Building a Foreign Office will provide the necessary training and organisation, in order to increase your city's radius of visibility and detection by 10% per level of Office.</br>You may build multiple Foreign Offices; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        57: ["Arctic Warfare College", 0, "For those troops who wish to push themselves further and harder, the Arctic Warfare College provides the training and means for your armies to fight, and survive, in the freezing, and uniquely hostile, environment of the North.</br>Attack and defence capabilities of all your city's troops who are fighting in this biome are increased by 1% per level of College.</br>You may build multiple Arctic Warfare Colleges; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        58: ["Desert Warfare College", 0, "To be effective in the desert, troops who train at the Desert Warfare College are well-equipped to fight and survive in the extreme heat and cold of this unique, and hostile, environment.</br>Attack and defence capabilities of all your city's troops who are fighting in this biome are increased by 1% per level of College.</br>You may build multiple Desert Warfare Colleges; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        59: ["Jungle Warfare College", 0, "The unique and hostile environment of the jungle, with its almost intolerable heat, combined with incredibly high humidity, has, it is said, but one aim... to kill and subsume living flesh into the biological whole. Graduates of the Jungle Warfare College understand this, and are well-equipped, both physically and mentally, for warfare and survival in this situation.</br>Attack and defence capabilities of all your city's troops who are fighting in this biome are increased by 1% per level of College.</br>You may build multiple Jungle Warfare Colleges; however, each subsequent one, while costing the same as the first, only performs half as effectively as its predecessor (i.e. the second building performs half as well as the first , while the third is half as effective as the second, and a quarter as effective as the first)."],
        60: ["Swordsmith", 1497, "A Swordsmith is no common blacksmith, crafting any metal goods his customers might request. Rather, the Swordsmith is a specialist, dedicated to producing very specific, superior weaponry, either for your troops to use, or for your merchants to trade. Here they live, sleep, study, and practise, heading out to work, at your request, at the Blacksmith. Note that the Swordsmiths actually produce their weapons in your existing Blacksmith, working to upgrade basic weapons into their masterpieces. Therefore, they will require basic Swords to work with, and their efforts will take up production time in your Blacksmith.</br>You can research each improved Sword type from the Crafting tab on the Research tree. Once you have completed one or more Researches, go to the Production tab in your Blacksmith to produce these specialist weapons."],
        61: ["Plate Armourer", 1497, "With the build of a burly blacksmith and the shrewd eye of a master tailor, Plate Armourers take basic, simple Plate, and return with it to the Forge, where they modify and upgrade it. At this building, they live, sleep, study, and practise, heading out to work, at your request, in the Forge. Note that the Plate Armourers actually produce their wares in your existing Forge, working to upgrade basic Plate Armour into their masterpieces. Therefore, they will require basic Plate to work with, and their efforts will take up production time in your Forge.</br>You can research each improved Plate armour type from the Crafting tab on the Research tree. Once you have completed one or more Researches, go to the Production tab in your Forge to produce these specialist armours."],
        62: ["Horse Trainer", 1497, "In the Paddock yard, the Horse Trainers hone their skills in commanding and training your horses. In the building itself, other workers devise special diets for the horses, mix feed for them, concoct rubs and potions for them, and fix the equipment used by the Trainers. This is a place of study, practise, and preparation. When the Horse Trainers work, taking simple horses and turning them into healthier, better-trained, fitter specimens, they do so in the Paddock. Note that because the Horse Trainers actually do their work in your existing Paddock, training existing horses, they will require horses to work with, and time in the Paddock.</br>You can research specific types of horses from the Crafting tab on the Research tree. Once you have completed one or more Researches, go to the Production tab in your Paddock to train these specialist mounts."],
        63: ["Skinners Guild", 1497, "Almost every part of an animal can be used in some way, as the d�cor of the Skinners\' Guild attests. Behind leather curtains, bone cups and spoons line the dining table, where animal fat is burned in antler or hide lanterns, while drink is poured out of wineskins, and meaty stews and roasts are served up for your tired workers, as they sit at fur-covered benches. Here the Skinners relax, sleep, and study after each strenuous foray into the wilds. And here also, the proceeds of their scavenging is scraped, crushed, boiled, pickled, oiled, filed, or otherwise prepared and preserved for use.</br>A Skinners' Guild allows you to recruit specialist Skinners who can pick out the rare, exotic, and sometimes magical, hides, organs, bones, and fangs from patches of Hides in the wilderness. In each Skinners' Guild, you may maintain one Skinner per level of the building. You may build more than one Skinners' Guild in your town, allowing you to recruit and direct more Skinners.</br>To recruit Skinners, go to the Train Trade Units icon at the top of the screen, or go to your Market and click on the Production tab."],
        64: ["Miners Guild", 1497, "Caked with mud and dust, your Miners return to the Miners' Guild after each strenuous foray into the wilds. Here they store their picks and shovels, relax, eat, sleep, and study, before heading out again to sift the earth and stone of Illyria for valuable minerals. And here a staff of specialist craftsmen sift and process the minerals which are brought back.</br>A Miners' Guild allows you to recruit specialist Miners who can seek out the rare, exotic, and sometimes magical, ores, crystals, gems, and rocks found in some Mineral patches. For each level of the Guild building, you may support one Miner. You may build more than one Miners' Guild in your town, allowing you to recruit and direct more Miners./br>To recruit Miners, go to the Train Trade Units icon at the top of the screen, or go to your Market and click on the Production tab."],
        65: ["Herbalists Guild", 1497, "Bundles of leaves and roots hang from rafters to dry, workers grind herbs in mortars, and tend to delicate alembics. Here the herbs gathered by your Herbalists are processed, and here these workers live, eat, and rest between forays into the wilderness.</br>A Herbalists' Guild allows you to recruit Herbalists who can seek out the rare, exotic, and sometimes magical, herbs from some of the Herb patches which dot the wilderness of Illyria. You may maintain one Herbalist per level of this building, and you may build more than one Herbalists' Guild in your town, allowing you to recruit and direct more Herbalists.</br>To recruit Herbalists, go to the Train Trade Units icon at the top of the screen, or go to your Market and click on the Production tab."],
        66: ["Merchants Guild", 1510, " An impressive Guild building, finely upholstered chairs, silver goblets, sumptuously cooked meats... these things are not necessities to most people's minds; however, to attract the right talent, it is important to make the right impression. If an ambitious Trader is considering signing a contract to serve your settlement, you will want to impress him. The contract negotiations will be simpler and swifter if the Trader has already been charmed by the lifestyle to which he may become accustomed, should he agree to work for you.</br>The Merchant's Guild organises the recruitment of Traders who have the wit, skill, ambition, and naked greed necessary to represent your interests in distant lands. Each level of the building reduces the time necessary to produce a Trader unit. To recruit a Trader, go to the Train Trade Units icon at the top of the screen, or go to your Market and click on the Production tab in your Market."],
        67: ["Cottage", 4, "This meagre dwelling is home to a poor peasant family. They scrape a living from the land of this otherwise unwanted building plot, keeping chickens or a goat, planting simple vegetables, and doing odd jobs around town for a coin here or there. As they have no money, they provide labour service to you. Each Cottage allows you to recruit a Cotter via your Market.</br>You may build this building any number of times in your settlement.</br>Once you have built one or more Cottages, you may go to the Train Trade Units icon at the top of the screen, or go to your Market and click on the Production tab, to recruit Cotters."],
        68: [],
        69: [],
        70: [],
        71: [],
        72: ["Trade Office", 2000, " As trade grows from a local concern to a world-spanning enterprise, it is not just a question of merchants haggling in markets and caravans trekking through the wilderness. A whole support staff is required, of clerks, quartermasters, mathematicians, grooms, stewards.... The better developed your Trade Office, the more researches you can unlock, allowing you to maintain a more complex trading operation across Illyria."],
        73: ["Spearsmith", 1497, " A Spearsmith is no common poleturner, churning out pitchforks and scythes alongside simple spears. Rather, the Spearsmith is a specialist weaponsmith, dedicated to producing very specific, superior weaponry, either for your troops to use or your merchants to trade. Here they live, sleep, study and practice, heading out to work at your request at the Spearmaker. Note that the Spearsmiths actually produce their weapons in your existing Spearmaker, working to upgrade basic weapons into their masterpieces. Therefore, they will require basic spears to work with, and their efforts will take up production time in your Spearmaker.</br>You can research each improved Spear type from the Crafting tab on the Research tree. Once you have completed one or more Researches, go to the Production tab in your Spearmaker to produce these specialist weapons."],
        74: ["Bowyer", 1497, "A Bowyer is a specialist, dedicated to producing very specific, superior weaponry, working with exotic woods, and even bone and metal. Here they live, sleep, study and practice, heading out to work at your request at the Fletcher. Note that the Bowyers actually produce their weapons in your existing Fletcher, working to upgrade basic weapons into their masterpieces. Therefore, they will require basic bows to work with, and their efforts will take up production time in your Fletcher.</br>You can research each improved Bow type from the Crafting tab on the Research tree. Once you have completed one or more Researches, go to the Production tab in your Fletcher to produce these specialist weapons."],
        75: ["Chain Armourer", 1497, "Chain Armourers take basic, simple Chain, and return with it to the Blacksmith, where they add and remove single links or panels of chain, add backing materials or overlays, and so modify and upgrade it. At this building they live, sleep, study and practice, heading out to work at your request at the Forge. Note that the Chain Armourers actually produce their wares in your existing Blacksmith, working to upgrade basic armour into their masterpieces. Therefore, they will require basic Chain to work with, and their efforts will take up production time in your Blacksmith.</br>You can research each improved Chain armour type from the Crafting tab on the Research tree. Once you have completed one or more Researches, go to the Production tab in your Blacksmith to produce these specialist armours."],
        76: ["Leather Armourer", 1497, "Leather Armourers take basic suits of Leather, and return with it to the Tanner, where they add stiffen, support, add, remove and augment panels of leather, and so modify and upgrade it. At this building they live, sleep, study and practice, heading out to work at your request at the Tanner. Note that the Leather Armourers actually produce their wares in your existing Tanner, working to upgrade basic armour into their masterpieces. Therefore, they will require basic Leather to work with, and their efforts will take up production time in your Tannery.</br>You can research each improved Leather armour type from the Crafting tab on the Research tree. Once you have completed one or more Researches, go to the Production tab in your Tannery to produce these specialist armours."]
    },
    /* Object: maxPops
     * The maximum possible population of each building. Organised by building name.
     */
    maxPops: {"Wall": 20, "Storehouse": 37, "Lumberjack": 37, "Clay Pit": 37, "Iron Mine": 37, "Quarry": 37, "Farmyard": 37, "Library": 37, "Barracks": 37, "Marketplace": 37, "Brewery": 40, "Tavern": 1497, "Consulate": 1497, "Carpentry": 1497, "Kiln": 1497, "Foundry": 1497, "Stonemason": 1497, "Flourmill": 16, "Common Ground": 1497, "Paddock": 1497, "Vault": 37, "Mage Tower": 1497, "Fletcher": 1497, "Spearmaker": 1497, "Blacksmith": 1497, "Forge": 1497, "Tannery": 1497, "Saddlemaker": 1497, "Siege Workshop": 1497, "Book Binder": 1497, "Warehouse": 370, "Chancery of Estates": 449, "Runemasters Grounding": 898, "Geomancers\' Retreat": 898, "Scouts\' Lookout": 898, "Spies\' Hideout": 898, "Thieves\' Den": 898, "Saboteurs\' Sanctuary": 898, "Assasins\' Abode": 898, "Spearmens\' Billets": 1796, "Archers\' Field": 1796, "Infantry Quarters": 1796, "Cavalry Parade Ground": 1796, "Architects\' Office": 328, "Foreign Office": 898, "Arctic Warfare College": 0, "Desert Warfare College": 0, "Jungle Warfare College": 0, "Swordsmith": 1497, "Plate Armourer": 1497, "Horse Trainer": 1497, "Skinner\'s Guild": 1497, "Miner\'s Guild": 1497, "Herbalist\'s Guild": 1497, "Merchant\'s Guild": 1510, "Cottage": 4, "Trade Office": 2000, "Spearsmith": 1497, "Bowyer": 1497, "Chain Armourer": 1497, "Leather Armourer": 1497}

};
