/*File: wartow.js
 * Test version of the main script to try and resolve timing issues. 
 * Defines the objects used in the tools and all the functions that are called 
 * by the tools. By making all the functions etc methods of this it removes any 
 * possibility of conflict with functions defined by the in-game scripts.
 */
dt = {
    currentData: "",
    server: 'https://www.wartow.dewt.me.uk',
    factionScanState: false,
    processingHash: false,
    db: null,
    mdb: null,
    oldH: '',
    popupStates: {"MilSumm": false, "AllQs": false, "IdleQs": false, "ProdNotices": false, "BaseInvs": false, "HubSum": false, "StoredTrades": false, "MovCoord": false},
    sCollectables: {},

    /* *************************************************************************
     * Object Definitions
     ************************************************************************* */
    /*Object: player
     * Holds all data relating to a player
     * 
     * Properties:
     * name - string. The name of the player.
     * alliance - integer. The id of the alliance this player belongs to. Is 0 if not in an alliance.
     * towns - object. Data relating to the towns owned by this player. See <town> for details of the structure.
     * hubs - object. Data relating to the hubs the player has goods stored at. See <hubs> for details of the structure.
     * settings - object. Settings for various tools.
     * pres - integer. The current amount of Prestige in this players account.
     * toolSettings - object. Position and size settings for each of the tools.
     * prodNotices - array. Details of each item production queue that has finished.
     * sieges - object. This will hold details of any ongoing sieges the player is involved in. These tools have not been written yet.
     */
    player: function (name, alliance, towns, hubs, settings, pres, toolSettings, prodNotices, sieges) {
        this.name = name;
        this.alliance = alliance;
        this.towns = towns;
        this.hubs = hubs;
        this.settings = settings;
        this.toolSettings = toolSettings;
        this.prodNotices = [];
        this.sieges = {};
        this.factions = {};
    },
    /* Object: town
     * Holds all data relating to a particular town.
     * 
     * Properties:
     * name - string. The name of the town.
     * x - integer. X coordinate of the town.
     * y - integer. Y coordinate of the town.
     * inv - object. Details of the inventory held by this town. See <inv> for details of the structure.
     * alembine - object. Status of this towns visits to each of the Allembine sites.
     * mil - object. Details of the troops currently in this town or being built there and the attack/defence scores for the town. See <mil> for details of the structure.
     * diplo - object. Details of the diplomatic units currently in this town as well as the diplomatic defence scores for this town. See <diplo> for details of the structure.
     * trade - details of the trade units currently in this town. See <trade> for details of the structure.
     * plots - object. Details of the building plots in the town. The plots are split into two objects internal and resource. The internal object holds details of the buildings on each of the plots inside (and including) the town wall while the resource holds the same details for the resource (wood, clay, iron etc) plots available to the town.
     * sov - array. An array of objects. Each object holds info on a sovereignty claim made by this town.
     */
    town: function (name, x, y, inv, allembine, mil, diplo, trade, prod, plots, sov) {
        this.name = name;
        this.x = x;
        this.y = y;
        this.inv = inv;
        this.allembine = allembine;
        this.mil = mil;
        this.diplo = diplo;
        this.trade = trade;
        this.prod = prod;
        this.plots = plots;
        this.sov = [];
    },
    /* Object: inv
     * Holds all data on the items held in the town. The items are organized into the same categories as the tabs at the bottom of the Inventory page.
     * 
     * Properties:
     * maxStore - integer. The maximum storage capacity in this town.
     * res - object. Details of base and advanced resources held in this town. For each resource a property is created which is an instance of the <item> object.
     * mounts - object. Details of any specialist mounts held in this town. For each mount type a property is created which is an instance of the <item> object.
     * weapons - object. Details of any specialist weapons held in this town. For each weapon a property is created which is an instance of the <item> object.
     * armour - object. Details of any specialist armour held in this town. For each armour a property is created which is an instance of the <item> object.
     * anatomies - object. Details of any animal parts and hides held in this town. For each anatomy a property is created which is an instance of the <item> object.
     * minerals - object. Details of any minerals (rare and common) held in this town. For each mineral a property is created which is an instance of the <item> object.
     * herbs - object. Details of any herbs (rare and common) held in this town. For each herb a property is created which is an instance of the <item> object.
     * exotic - object. Details of any exotic items held in this town. For each exotic item a property is created which is an instance of the <item> object.
     */
    inv: function (maxStore, res, mounts, weapons, armour, anatomies, minerals, herbs, exotic) {
        this.maxStore = maxStore;
        if (Object.getOwnPropertyNames(res).length > 0) {
            this.res = res;
        } else {
            this.res = {
                "Gold": {"id": "i=4|1", "held": 0, "rate": 0, "classes": " resIcon ico-gold"},
                "Wood": {"id": "i=1|1", "held": 0, "rate": 0, "classes": " resIcon ico-wood"},
                "Clay": {"id": "i=1|2", "held": 0, "rate": 0, "classes": " resIcon ico-clay"},
                "Iron": {"id": "i=1|3", "held": 0, "rate": 0, "classes": " resIcon ico-iron"},
                "Stone": {"id": "i=1|4", "held": 0, "rate": 0, "classes": " resIcon ico-stone"},
                "Food": {"id": "i=1|5", "held": 0, "rate": 0, "classes": " resIcon ico-food"},
                "Mana": {"id": "i=2|1", "held": 0, "rate": 0, "classes": " resIcon ico-mana"},
                "Research": {"id": "i=2|2", "held": 0, "rate": 0, "classes": " resIcon ico-research"},
                "Horse": {"id": "i=3|1", "held": 0, "rate": 0, "classes": " resIcon ico-horses"},
                "Livestock": {"id": "i=3|2", "held": 0, "rate": 0, "classes": " resIcon ico-livestock"},
                "Beer": {"id": "i=3|12", "held": 0, "rate": 0, "classes": " resIcon ico-beer"},
                "Book": {"id": "i=3|7", "held": 0, "rate": 0, "classes": " resIcon ico-books"},
                "Spear": {"id": "i=3|5", "held": 0, "rate": 0, "classes": " resIcon ico-spears"},
                "Sword": {"id": "i=3|3", "held": 0, "rate": 0, "classes": " resIcon ico-swords"},
                "Bow": {"id": "i=3|4", "held": 0, "rate": 0, "classes": " resIcon ico-bows"},
                "Saddle": {"id": "i=3|6", "held": 0, "rate": 0, "classes": " resIcon ico-saddles"},
                "Leather Armour": {"id": "i=3|8", "held": 0, "rate": 0, "classes": " resIcon ico-leather"},
                "Chainmail": {"id": "i=3|9", "held": 0, "rate": 0, "classes": " resIcon ico-chainmail"},
                "Plate Armour": {"id": "i=3|10", "held": 0, "rate": 0, "classes": " resIcon ico-plate"},
                "Siege Block": {"id": "i=3|11", "held": 0, "rate": 0, "classes": " resIcon ico-siege"}
            };
        }
        this.mounts = mounts;
        this.weapons = weapons;
        this.armour = armour;
        this.anatomies = anatomies;
        this.minerals = minerals;
        this.herbs = herbs;
        this.exotic = exotic;
    },

    /* *************************************************************************
     * Common Methods
     ************************************************************************* */

    /* Method: addElement2
     * Create and append an element with multiple attributes
     *
     * Parameters:
     * assignTo - the global name that this element should be given.
     * parent - the element the element is to be appended to
     * elementType - the type of element to add.
     * attribVal - array holding the values to be given to the attributes
     * attribName - array holding the names of the attributes to be added.
     *
     * Returns:
     * The new element.
     */

    addElement: function (assignTo, parent, elementType, attribNames, attribVals) {
        var newElem = document.createElement(elementType);
        if (attribNames) {
            var numAttribs = attribNames.length;
            if (numAttribs > 0) {
                for (var i = 0; i < numAttribs; i++) {
                    switch (attribNames[i]) {
                        case 'textContent':
                            newElem.textContent = attribVals[i];
                            break;
                        case 'innerHTML':
                            newElem.innerHTML = attribVals[i];
                            break;
                        default:
                            newElem.setAttribute(attribNames[i], attribVals[i]);
                            break;
                    }
                }
            }
        }
        try {
            if (document.querySelector(parent) !== null) {
                var newDiv = document.querySelector(parent).appendChild(newElem);
            } else {
                var newDiv = document.getElementById(parent).appendChild(newElem);
            }
        } catch (e) {
            var newDiv = parent.appendChild(newElem);
        }
        if (assignTo !== '') {
            dt[assignTo] = newDiv;
        }
        return newDiv;
    },
    /* Method: addElement2
     * Create and append an element with multiple attributes
     *
     * Parameters:
     * parent - the element the element is to be appended to
     * elementType - the type of element to add.
     * attribVal - array holding the values to be given to the attributes
     * attribName - array holding the names of the attributes to be added.
     *
     * Returns:
     * The new element.
     */
    addElement2: function (parent, elementType, attribName, attribVal) {
        var newElem = document.createElement(elementType);
        if (attribName) {
            var numAttribs = attribName.length;
            if (numAttribs > 0) {
                for (var i = 0; i < numAttribs; i++) {
                    newElem.setAttribute(attribName[i], attribVal[i]);
                }
            }
        }
        var newDiv = parent.appendChild(newElem);
        return newDiv;
    },
    /* Method: removeRows
     * Remove all the rows from the body of a table.
     * 
     * Parameter:
     * tbl - object reference. The table to remove the rows from.
     */
    removeRows: function (tbl) {
        var bdy = tbl.querySelector('tbody');
        if (bdy.hasChildNodes()) {
            while (bdy.firstChild) {
                bdy.removeChild(bdy.firstChild);
            }
        }
    },

    /* *************************************************************************
     * Tool Setup & Load Methods
     ************************************************************************* */

    /* Method: scriptLoader
     * Load the scripts held in the scriptList array.
     */
    scriptLoader: function () {
        var scriptList = [
            dt.server + '/js-sub/idb8.js',
            dt.server + '/js-sub/inventory7.js',
            dt.server + '/js-sub/military8.js',
            dt.server + '/js-sub/diplo2.js',
            dt.server + '/js-sub/maptools3.js',
            dt.server + '/js-sub/trade3.js',
            dt.server + '/js-sub/data3.js',
            dt.server + '/js-sub/quests.js',
            dt.server + '/js-sub/crafting.js',
            dt.server + '/js-sub/mail.js',
            dt.server + '/js-sub/buildings2.js',
            dt.server + '/js-sub/sovereignty3.js',
            dt.server + '/js-sub/mailsearch4.js',
            dt.server + '/js-sub/production6.js',
//            dt.server + '/js-sub/preferences.js',
            dt.server + '/js-sub/misc2.js',
            dt.server + '/js/tablesort.js',
            dt.server + '/js-sub/movCoordinator5.js',
            dt.server + '/js/intercept7.js',
            dt.server + '/js-sub/hubs4.js',
            dt.server + '/js-sub/popupWatcher5.js',
            dt.server + '/js-sub/mailFolders.js',
            dt.server + '/js-sub/projResUse.js',
            dt.server + '/js-sub/audrey.js',
            dt.server + '/js-sub/research.js',
            dt.server + '/js-sub/messageScan.js',
            dt.server + '/js-sub/profileUtils.js',
            dt.server + '/js-sub/dtui.js'
        ];

//          dt.server + '/js-sub/elementChecker.js',
        for (var i = 0; i < scriptList.length; i++) {
            $.ajax({
                url: scriptList[i],
                dataType: "script",
                cache: false
            }).done(function (data, status, jqxhr) {
//		jQuery.cookie("cookie_name", "value", { expires: 7 });
            });
        }
    },
    /* Function: getTownList
     * Parse the optTown element to get a list of all the towns owned by the current player and either update or create a <town> object to hold the data.
     * 
     */
    getTownList: function () {
        var townDivs = document.getElementsByClassName('cityMenu');
        var numTowns = townDivs.length;
        dt[PlayerId].towns.list = [];
        dt[PlayerId].towns.numTowns = numTowns;
        var list = [];
        for (var i = 0; i < numTowns; i++) {
            var townId = townDivs.item(i).getAttribute('data-townid');
            var name = townDivs.item(i).getElementsByTagName('div').item(0).textContent;
            name = name.replace("- Capital", "");
            name = name.trim();
            var coords = townDivs.item(i).getElementsByTagName('div').item(1).textContent;
            var coordArray = coords.split(' ');
            if (dt[PlayerId].towns.hasOwnProperty(townId) === false) {
                dt[PlayerId].towns[townId] = new dt.town(name, coordArray[0].trim(), coordArray[2].trim(), new dt.inv(0, {}, {}, {}, {}, {}, {}, {}, {}), '', '', '', '', {}, []);
            } else {
                dt[PlayerId].towns[townId].name = name;
                dt[PlayerId].towns[townId].x = coordArray[0].trim();
                dt[PlayerId].towns[townId].y = coordArray[1].trim();
            }
            dt[PlayerId].towns.list.push(townId);
        }
        // Check if the 'all' town exists and create if not
        if (!dt[PlayerId].towns.hasOwnProperty("all")) {
            dt[PlayerId].towns.all = {trade: {"storedTrades": []}};
        }

        dt[PlayerId].towns.list.sort();
    },
    
};

/* *************************************************************************
 * Code Executed on load
 ************************************************************************* */
dt.currentData = "";

var winWWidth = window.innerWidth;
var winHeight = window.innerHeight;
var logopos = document.getElementsByClassName('logo').item(0);
var style = window.getComputedStyle(logopos, null);
var left = (parseInt(style.getPropertyValue("left"))) + (parseInt(style.getPropertyValue("width")));

var struct = [
    {assignTo: '', parent: 'head', elType: 'link', attrNames: ['type', 'href', 'rel'], attrVals: ['text/css', dt.server + '/css/durcTools4.css', 'stylesheet']},
    {assignTo: 'topLevel', parent: 'body', elType: 'div', attrNames: ['id', 'style', 'class'], attrVals: ['durcTools3', 'border: solid; border-width: 3px; border-color: brown; overflow: visible; width: 320px;left:' + left + 'px;top:0px;', 'ui-widget-content nosee']},
    {assignTo: 'toolDivs', parent: 'body', elType: 'div', attrNames: ['id', 'class'], attrVals: ['toolDivs', 'nosee']}
];

for (var i = 0; i < struct.length; i++) {
    dt.addElement(struct[i].assignTo, struct[i].parent, struct[i].elType, struct[i].attrNames, struct[i].attrVals);
};
// Load the html for the tools top section
$("#durcTools3").load(dt.server + "/html/durctools7.html");
// Load the html for the actual tools
$("#toolDivs").load(dt.server + "/html/toolDivs3.html");

var durcbut = dt.addElement('', 'body', 'div', ['id', 'style', 'class'], ['durcbut', 'left:' + left + 'px;top:0px', 'see']);
durcbut.innerHTML = '<input class="durcbut" onclick="dt.durcbutToggle()" title="Click to open DurcTools v3">';
$(function () {
    $("#durcTools3").draggable({handle: "#dt_logo"});
});
// Create the player instance
dt[PlayerId] = new dt.player(CurPlayerName, YourAllianceId, {}, {}, {factionScanState: false, alertAudio: false, alertVisual: false, alertFreq: 10}, 0, [], {});
// Get the id and name of each of the player towns
dt.getTownList();

// Load the external scripts
dt.scriptLoader();

